package org.kantega.jexmec.test;

/*
 * Copyright 2011 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.commons.io.IOUtils;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.security.SecureRandom;
import java.util.Collections;
import java.util.Random;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;

/**
 *
 */
public class TestUtils {

    private static Random random = new SecureRandom();

    public static File getPluginWorkDirectory(String module) {
        return getPluginWorkDirectory(module, false);
    }

    public static File getPluginWorkDirectory(String module, boolean clean) {
        File target = getTargetDirectory(module);

        final File work = new File(target, "pluginworkdirectory-" + random.nextLong());
        if (clean) {
            deleteDirectory(work);
        }
        work.mkdirs();
        return work;

    }

    private static void deleteDirectory(File work) {
        if(work.isFile()) {
            work.delete();
        } else if(work.isDirectory()) {
            for(File file : work.listFiles()) {
                deleteDirectory(work);
            }
        }
    }

    private static File getTargetDirectory(String module) {
        File target = new File("target");
        if (!target.exists()) {
            target = new File( module + "/target");
        }
        if (!target.exists()) {
            throw new IllegalStateException("Could not find target directory");
        }
        return target;
    }

    public  static void unpackJarFile(File pluginFile, File pluginDirectory) throws IOException {
        JarFile file = new JarFile(pluginFile);
        for (JarEntry entry : Collections.list(file.entries())) {
            File outFile = new File(pluginDirectory, entry.getName());
            if(entry.isDirectory()) {
                outFile.mkdirs();
            } else {
                outFile.getParentFile().mkdirs();
                FileOutputStream output = new FileOutputStream(outFile);
                IOUtils.copy(file.getInputStream(entry), output);
                output.close();
            }
            outFile.setLastModified(System.currentTimeMillis()-60000);
        }
    }
}
